@@ -47,7 +47,7 @@ class GemText:
     lines = []
 
     def __init__(self):
-        pass
+        self.lines = []
 
     def deepcopy(self):
         result = GemText()
